nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Audiopll0denom

Struct Audiopll0denom 

#[repr(transparent)]
pub struct Audiopll0denom(pub u32);
Audio pll0 denom

Tuple Fields

0: u32

Implementations

Source

impl Audiopll0denom

pub const fn denom(&self) -> u32

This field contains the denominator of the AUDIOPLL0 fractional loop divider. NOTES: 1. The value of numerator must always be configured to be less than the value of the denominator. 2. The AUDIOPLL0DENOM register can only be changed when the AUDIOPLL0 is disabled.

pub const fn set_denom(&mut self, val: u32)

This field contains the denominator of the AUDIOPLL0 fractional loop divider. NOTES: 1. The value of numerator must always be configured to be less than the value of the denominator. 2. The AUDIOPLL0DENOM register can only be changed when the AUDIOPLL0 is disabled.