nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Audiopll0locktimediv2

Struct Audiopll0locktimediv2 

#[repr(transparent)]
pub struct Audiopll0locktimediv2(pub u32);
audio pll0 lock time

Tuple Fields

0: u32

Implementations

Source

impl Audiopll0locktimediv2

pub const fn locktimediv2(&self) -> u16

AUDIOPLL0 Lock Time Divide by 2: Programmed lock time is in uS (micro-seconds) and is programmed as half the actual lock time value.

pub const fn set_locktimediv2(&mut self, val: u16)

AUDIOPLL0 Lock Time Divide by 2: Programmed lock time is in uS (micro-seconds) and is programmed as half the actual lock time value.