#[repr(transparent)]pub struct Audiopll0num(pub u32);Expand description
audio pll0 number
Tuple Fields
0: u32Implementations
Sourceimpl Audiopll0num
impl Audiopll0num
Sourcepub const fn num(&self) -> u32
pub const fn num(&self) -> u32
This field contains the numerator of the AUDIOPLL0 fractional loop divider. NOTES: 1. The value of numerator must always be configured to be less than the value of the denominator. 2. The AUDIOPLL0NUM register can only be changed when the AUDIOPLL0 is disabled.
Sourcepub const fn set_num(&mut self, val: u32)
pub const fn set_num(&mut self, val: u32)
This field contains the numerator of the AUDIOPLL0 fractional loop divider. NOTES: 1. The value of numerator must always be configured to be less than the value of the denominator. 2. The AUDIOPLL0NUM register can only be changed when the AUDIOPLL0 is disabled.