nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Frg15ctl

Struct Frg15ctl 

#[repr(transparent)]
pub struct Frg15ctl(pub u32);
FRG clock controller 15

Tuple Fields

0: u32

Implementations

Source

impl Frg15ctl

pub const fn div(&self) -> u8

Denominator of the fractional divider. DIV is equal to the programmed value +1. Always set to 0xFF to use with the fractional baud rate generator.

pub const fn set_div(&mut self, val: u8)

Denominator of the fractional divider. DIV is equal to the programmed value +1. Always set to 0xFF to use with the fractional baud rate generator.

pub const fn mult(&self) -> u8

Numerator of the fractional divider. MULT is equal to the programmed value.

pub const fn set_mult(&mut self, val: u8)

Numerator of the fractional divider. MULT is equal to the programmed value.