#[repr(transparent)]pub struct Audiopll0denom(pub u32);Expand description
Audio pll0 denom
Tuple Fields
0: u32Implementations
Sourceimpl Audiopll0denom
impl Audiopll0denom
Sourcepub const fn denom(&self) -> u32
pub const fn denom(&self) -> u32
This field contains the denominator of the AUDIOPLL0 fractional loop divider. NOTES: 1. The value of numerator must always be configured to be less than the value of the denominator. 2. The AUDIOPLL0DENOM register can only be changed when the AUDIOPLL0 is disabled.
Sourcepub const fn set_denom(&mut self, val: u32)
pub const fn set_denom(&mut self, val: u32)
This field contains the denominator of the AUDIOPLL0 fractional loop divider. NOTES: 1. The value of numerator must always be configured to be less than the value of the denominator. 2. The AUDIOPLL0DENOM register can only be changed when the AUDIOPLL0 is disabled.