#[repr(transparent)]pub struct Frg15ctl(pub u32);Expand description
FRG clock controller 15
Tuple Fields
0: u32Implementations
Sourceimpl Frg15ctl
impl Frg15ctl
Sourcepub const fn div(&self) -> u8
pub const fn div(&self) -> u8
Denominator of the fractional divider. DIV is equal to the programmed value +1. Always set to 0xFF to use with the fractional baud rate generator.
Sourcepub const fn set_div(&mut self, val: u8)
pub const fn set_div(&mut self, val: u8)
Denominator of the fractional divider. DIV is equal to the programmed value +1. Always set to 0xFF to use with the fractional baud rate generator.