#[repr(transparent)]pub struct Frgctl(pub u32);Expand description
FRG clock controller
Tuple Fields
0: u32Implementations
Sourceimpl Frgctl
impl Frgctl
Sourcepub const fn div(&self) -> u8
pub const fn div(&self) -> u8
Denominator of the fractional divider. DIV is equal to the programmed value +1. Always set to 0xFF to use with the fractional baud rate generator.
Sourcepub const fn set_div(&mut self, val: u8)
pub const fn set_div(&mut self, val: u8)
Denominator of the fractional divider. DIV is equal to the programmed value +1. Always set to 0xFF to use with the fractional baud rate generator.